@@ -1,22 +1,27 @@
 #!/usr/bin/env python3
 
+import functools
+import json
+import logging
+import os
+import sys
+import argparse
 from getpass import getpass
 from pathlib import Path
-from prompt_toolkit import prompt
-from prompt_toolkit.validation import ValidationError, Validator
-from requests.exceptions import HTTPError
+
 from src.clients.api import API
 from src.clients.db import DB
 from src.clients.s3 import S3
 from src.utils import (download_file, recurse_object, validate_project_name,
                        verify_file_type)
-from tabulate import tabulate
 
+from prompt_toolkit import prompt
+from prompt_toolkit.validation import ValidationError, Validator
+from requests.exceptions import HTTPError
+from tabulate import tabulate
+from cfg_cli import __version__
 import fire
-import functools
-import json
-import logging
-import os
+
 
 
 def catch_errors(func):
@@ -25,7 +30,7 @@ def catch_errors(func):
         try:
             return func(*args, **kwargs)
         except Exception as e:
-            if os.getenv("APP_ENV") == "LOCAL":
+            if os.getenv("PRISM_ENV") == "DEV":
                 logging.exception(e)
             if isinstance(e, HTTPError) and e.response.json().get("message"):
                 raise fire.core.FireError(Exception(e.response.json().get("message")))
@@ -41,9 +46,9 @@ class PrismCLI(object):
     This is the Python interface for CLI commands, the CLI command `prism` instantiates this class and sub commands correspond to methods of this object.
     """
     
-    def login(self):
+    def login(self, username="", password=""):
         """
-        Login and create a session. 
+        Login with your cofactor credentials.
 
         Login in with your email and password.
 
@@ -52,16 +57,21 @@ class PrismCLI(object):
             username: example_user@gmail.com
             password:
             Successfully logged in.
+
+            >>> prism login --username user@example.com --password example_password
+            Successfully logged in.
         """
 
         @catch_errors
-        def inner():
-            username = input("username: ")
-            password = getpass()
-            API.login(username=username, password=password)
-            print("Successfully logged in.")
+        def inner(username, password):
+            if username == "":
+                username = input("username: ")
+            if password == "":
+                password = getpass()
+            if API.login(username=username, password=password):
+                print("Successfully logged in.")
 
-        inner()
+        inner(username, password)
 
     def logout(self):
         """
@@ -238,6 +248,7 @@ class PrismCLI(object):
         """ 
         Submit analysis for specified project.
 
+        A submition for a project can only be done once. If an error was made a new project will need to be created in order to run the run the analysis correctly. 
         Groupings argument is a JSON representation of how the fastqs should be grouped for analysis.
         Ex: '{"GRP1": ["fastqs1.txt.gz", "fastqs1.txt.gz", ...], "GRP2": ["fastqs3.txt.gz", "fastqs4.txt.gz", ...]}'
         Note the single quote at the beginning and end of the json.
@@ -341,8 +352,13 @@ class PrismCLI(object):
 
 
 def wrapper():
-    if os.getenv("APP_ENV") == "LOCAL":
+    if os.getenv("PRISM_ENV") == "DEV":
         logging.basicConfig(level=logging.INFO)
+    parser = argparse.ArgumentParser()
+    parser.add_argument("-v", "--version", action="store_true")
+    if parser.parse_args():
+        print(__version__)
+        sys.exit()
     fire.Fire(PrismCLI())
 
 
